Module: AstroSubframeOrganizer::Commands

Extended by:
Dry::CLI::Registry
Defined in:
lib/astro_subframe_organizer/commands.rb,
lib/astro_subframe_organizer/commands/run.rb,
lib/astro_subframe_organizer/commands/init.rb,
lib/astro_subframe_organizer/commands/inspect.rb,
lib/astro_subframe_organizer/commands/version.rb,
lib/astro_subframe_organizer/commands/organize/base.rb,
lib/astro_subframe_organizer/commands/organize/bias.rb,
lib/astro_subframe_organizer/commands/organize/darks.rb,
lib/astro_subframe_organizer/commands/organize/flats.rb,
lib/astro_subframe_organizer/commands/shared_options.rb,
lib/astro_subframe_organizer/commands/organize/lights.rb,
lib/astro_subframe_organizer/commands/raw/revert_name.rb,
lib/astro_subframe_organizer/commands/equipment_options.rb,
lib/astro_subframe_organizer/commands/cleanup/thumbnails.rb,
lib/astro_subframe_organizer/commands/cleanup/unorganize.rb,
lib/astro_subframe_organizer/commands/raw/rename_from_exif.rb,
lib/astro_subframe_organizer/commands/cleanup/empty_directories.rb

Overview

The main command registry for the AstroSubframeOrganizer CLI, using Dry::CLI to define and organize commands and their aliases. This module registers all the available commands for the CLI, including:

  • Version display

  • Initialization of configuration

  • Running the organizer in interactive mode

  • Inspecting file metadata

  • Organizing different types of subframes (lights, darks, flats, biases)

  • Renaming RAW files based on EXIF data

  • Cleaning up thumbnails and empty directories

  • Reverting organization changes

Defined Under Namespace

Modules: Cleanup, EquipmentOptions, Organize, Raw, SharedOptions Classes: Init, Inspect, Run, Version