Class: AstroSubframeOrganizer::Equipment::Camera

Inherits:
Object
  • Object
show all
Defined in:
lib/astro_subframe_organizer/equipment/camera.rb

Overview

Add your filters to ‘~/astro-subframe-organizer-config.yml`. If there is more than one, and no camera is automatically detected, you will be prompted to choose one of them when organizing subframes.

Class Method Summary collapse

Class Method Details

.allObject



9
10
11
# File 'lib/astro_subframe_organizer/equipment/camera.rb', line 9

def self.all
  Config.all_cameras
end