Class: AstroSubframeOrganizer::Equipment::Filter
- Inherits:
-
Object
- Object
- AstroSubframeOrganizer::Equipment::Filter
- Defined in:
- lib/astro_subframe_organizer/equipment/filter.rb
Overview
Add your filters to ‘~/astro-subframe-organizer-config.yml`. If there is more than one, you will be prompted to choose one of them when organizing flats and lights.
Class Method Summary collapse
Class Method Details
.all ⇒ Object
9 10 11 |
# File 'lib/astro_subframe_organizer/equipment/filter.rb', line 9 def self.all Config.all_filters end |