Module: FileUtils
- Defined in:
- lib/astro_subframe_organizer/utils/file_utils.rb
Overview
rubocop:disable Style/Documentation
Class Method Summary collapse
-
.fu_output_message(msg) ⇒ Object
We redefine the internal output method used by FileUtils.
Class Method Details
.fu_output_message(msg) ⇒ Object
We redefine the internal output method used by FileUtils
7 8 9 |
# File 'lib/astro_subframe_organizer/utils/file_utils.rb', line 7 def self.(msg) AstroSubframeOrganizer.logger.info(msg) end |