Class: AstroSubframeOrganizer::Equipment::Telescope
- Inherits:
-
Object
- Object
- AstroSubframeOrganizer::Equipment::Telescope
- Defined in:
- lib/astro_subframe_organizer/equipment/telescope.rb
Overview
Add your telescopes to ‘~/astro-subframe-organizer-config.yml`. If there is more than one, you will be prompted to choose one of them when organizing flats and lights.
Class Method Summary collapse
Class Method Details
.all ⇒ Object
9 10 11 |
# File 'lib/astro_subframe_organizer/equipment/telescope.rb', line 9 def self.all Config.all_telescopes end |